% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CST_MultiEOF.R
\name{CST_MultiEOF}
\alias{CST_MultiEOF}
\title{EOF analysis of multiple variables}
\usage{
CST_MultiEOF(
  datalist,
  neof_max = 40,
  neof_composed = 5,
  minvar = 0.6,
  lon_lim = NULL,
  lat_lim = NULL
)
}
\arguments{
\item{datalist}{A list of objects of the class 's2dv_cube', containing the 
variables to be analysed. Each data object in the list is expected to have 
an element named \code{$data} with at least two spatial dimensions named 
"lon" and "lat", a dimension "ftime" and a dimension "sdate".}

\item{neof_max}{Maximum number of single eofs considered in the first 
decomposition.}

\item{neof_composed}{Number of composed eofs to return in output.}

\item{minvar}{Minimum variance fraction to be explained in first decomposition.}

\item{lon_lim}{Vector with longitudinal range limits for the EOF calculation 
for all input variables.}

\item{lat_lim}{Vector with latitudinal range limits for the EOF calculation 
for all input variables.}
}
\value{
A list with elements \code{$coeff} (an array of time-varying principal 
component coefficients), \code{$variance} (a matrix of explained variances),
\code{eof_pattern} (a matrix of EOF patterns obtained by regression for each 
variable).
}
\description{
This function performs EOF analysis over multiple variables,
accepting in input a list of CSTools objects. Based on Singular Value 
Decomposition. For each field the EOFs are computed and the corresponding PCs 
are standardized (unit variance, zero mean); the minimum number of principal 
components needed to reach the user-defined variance is retained. The function 
weights the input data for the latitude cosine square root.
}
\examples{
exp <- lonlat_temp$exp
exp$data <- ClimProjDiags::Subset(exp$data, along = c('lat', 'lon'), list(1:4, 1:4))
exp$lat <- exp$lat[1:4]
exp$lon <- exp$lon[1:4]

# Create three datasets (from the members)
exp1 <- exp
exp2 <- exp

exp1$data <- ClimProjDiags::Subset(exp$data, along = 2, indices = 1:5)
exp2$data <- ClimProjDiags::Subset(exp$data, along = 2, indices = 6:10)

cal <- CST_MultiEOF(list(exp1, exp2) , minvar = 0.9)
}
\author{
Jost von Hardenberg - ISAC-CNR, \email{j.vonhardenberg@isac.cnr.it}

Paolo Davini - ISAC-CNR, \email{p.davini@isac.cnr.it}
}
